grib2io.tables.section1 API documentation

# grib2io.tables.section1

View Source

      1table_1_0 = {
      2'0':'Experimental',
      3'1':'Version Implemented on 7 November 2001',
      4'2':'Version Implemented on 4 November 2003',
      5'3':'Version Implemented on 2 November 2005',
      6'4':'Version Implemented on 7 November 2007',
      7'5':'Version Implemented on 4 November 2009',
      8'6':'Version Implemented on 15 September 2010',
      9'7':'Version Implemented on 4 May 2011',
     10'8':'Version Implemented on 8 November 2011',
     11'9':'Version Implemented on 2 May 2012',
     12'10':'Version Implemented on 7 November 2012',
     13'11':'Version Implemented on 8 May 2013',
     14'12':'Version Implemented on 14 November 2013',
     15'13':'Version Implemented on 7 May 2014',
     16'14':'Version Implemented on 5 November 2014',
     17'16':'Version Implemented on 11 November 2015',
     18'17':'Version Implemented on 4 May 2016',
     19'18':'Version Implemented on 2 November 2016',
     20'19':'Version Implemented on 3 May 2017',
     21'20':'Version Implemented on 8 November 2017',
     22'21':'Version Implemented on 2 May 2018',
     23'22':'Version Implemented on 7 November 2018',
     24'23':'Version Implemented on 15 May 2019',
     25'24':'Version Implemented on 06 November 2019',
     26'25':'Pre-operational to be implemented by next amendment',
     27'25':'Version Implemented on 06 May 2020',
     28'26':'Version Implemented on 16 November 2020',
     29'27':'Version Implemented on 16 June 2021',
     30'28':'Version Implemented on 15 November 2021',
     31'29':'Version Implemented on 15 May 2022',
     32'30':'Version Implemented on 15 November 2022',
     33'31':'Version Implemented on 15 June 2023',
     34'32':'Version Implemented on 30 November 2023',
     35'33':'Version Implemented on 28 July 2024',
     36'34':'Pre-operational to be implemented by next amendment',
     37'35-254':'Future Version',
     38'255':'Missing"',
     39}
     40
     41table_1_1 = {
     42'0':'Local tables not used. Only table entries and templates from the current master table are valid.',
     43'1-254':'Number of local table version used.',
     44'255':'Missing',
     45}
     46
     47table_1_2 = {
     48'0':'Analysis',
     49'1':'Start of Forecast',
     50'2':'Verifying Time of Forecast',
     51'3':'Observation Time',
     52'4':'Local Time',
     53'5':'Simulation start',
     54'6-191':'Reserved',
     55'192-254':'Reserved for Local Use',
     56'255':'Missing',
     57}
     58
     59table_1_3 = {
     60'0':'Operational Products',
     61'1':'Operational Test Products',
     62'2':'Research Products',
     63'3':'Re-Analysis Products',
     64'4':'THORPEX Interactive Grand Global Ensemble (TIGGE)',
     65'5':'THORPEX Interactive Grand Global Ensemble (TIGGE) test',
     66'6':'S2S Operational Products',
     67'7':'S2S Test Products',
     68'8':'Uncertainties in ensembles of regional reanalysis project (UERRA)',
     69'9':'Uncertainties in ensembles of regional reanalysis project (UERRA) Test',
     70'10':'Copernicus Regional Reanalysis',
     71'11':'Copernicus Regional Reanalysis Test',
     72'12':'Destination Earth',
     73'13':'Destination Earth test',
     74'14-191':'Reserved',
     75'192-254':'Reserved for Local Use',
     76'255':'Missing',
     77}
     78
     79table_1_4 = {
     80'0':'Analysis Products',
     81'1':'Forecast Products',
     82'2':'Analysis and Forecast Products',
     83'3':'Control Forecast Products',
     84'4':'Perturbed Forecast Products',
     85'5':'Control and Perturbed Forecast Products',
     86'6':'Processed Satellite Observations',
     87'7':'Processed Radar Observations',
     88'8':'Event Probability',
     89'9-191':'Reserved',
     90'192-254':'Reserved for Local Use',
     91'192':'Experimental Products',
     92'255':'Missing',
     93}
     94
     95table_1_5 = {
     96'0':'Calendar Definition',
     97'1':'Paleontological Offset',
     98'2':'Calendar Definition and Paleontological Offset',
     99'3-32767':'Reserved',
    100'32768-65534':'Reserved for Local Use',
    101'65535':'Missing',
    102}
    103
    104table_1_6 = {
    105'0':'Gregorian',
    106'1':'360-day',
    107'2':'365-day',
    108'3':'Proleptic Gregorian',
    109'4-191':'Reserved',
    110'192-254':'Reserved for Local Use',
    111'255':'Missing',
    112}

table_1_0 = {'0': 'Experimental', '1': 'Version Implemented on 7 November 2001', '2': 'Version Implemented on 4 November 2003', '3': 'Version Implemented on 2 November 2005', '4': 'Version Implemented on 7 November 2007', '5': 'Version Implemented on 4 November 2009', '6': 'Version Implemented on 15 September 2010', '7': 'Version Implemented on 4 May 2011', '8': 'Version Implemented on 8 November 2011', '9': 'Version Implemented on 2 May 2012', '10': 'Version Implemented on 7 November 2012', '11': 'Version Implemented on 8 May 2013', '12': 'Version Implemented on 14 November 2013', '13': 'Version Implemented on 7 May 2014', '14': 'Version Implemented on 5 November 2014', '16': 'Version Implemented on 11 November 2015', '17': 'Version Implemented on 4 May 2016', '18': 'Version Implemented on 2 November 2016', '19': 'Version Implemented on 3 May 2017', '20': 'Version Implemented on 8 November 2017', '21': 'Version Implemented on 2 May 2018', '22': 'Version Implemented on 7 November 2018', '23': 'Version Implemented on 15 May 2019', '24': 'Version Implemented on 06 November 2019', '25': 'Version Implemented on 06 May 2020', '26': 'Version Implemented on 16 November 2020', '27': 'Version Implemented on 16 June 2021', '28': 'Version Implemented on 15 November 2021', '29': 'Version Implemented on 15 May 2022', '30': 'Version Implemented on 15 November 2022', '31': 'Version Implemented on 15 June 2023', '32': 'Version Implemented on 30 November 2023', '33': 'Version Implemented on 28 July 2024', '34': 'Pre-operational to be implemented by next amendment', '35-254': 'Future Version', '255': 'Missing"'}
table_1_1 = {'0': 'Local tables not used. Only table entries and templates from the current master table are valid.', '1-254': 'Number of local table version used.', '255': 'Missing'}
table_1_2 = {'0': 'Analysis', '1': 'Start of Forecast', '2': 'Verifying Time of Forecast', '3': 'Observation Time', '4': 'Local Time', '5': 'Simulation start', '6-191': 'Reserved', '192-254': 'Reserved for Local Use', '255': 'Missing'}
table_1_3 = {'0': 'Operational Products', '1': 'Operational Test Products', '2': 'Research Products', '3': 'Re-Analysis Products', '4': 'THORPEX Interactive Grand Global Ensemble (TIGGE)', '5': 'THORPEX Interactive Grand Global Ensemble (TIGGE) test', '6': 'S2S Operational Products', '7': 'S2S Test Products', '8': 'Uncertainties in ensembles of regional reanalysis project (UERRA)', '9': 'Uncertainties in ensembles of regional reanalysis project (UERRA) Test', '10': 'Copernicus Regional Reanalysis', '11': 'Copernicus Regional Reanalysis Test', '12': 'Destination Earth', '13': 'Destination Earth test', '14-191': 'Reserved', '192-254': 'Reserved for Local Use', '255': 'Missing'}
table_1_4 = {'0': 'Analysis Products', '1': 'Forecast Products', '2': 'Analysis and Forecast Products', '3': 'Control Forecast Products', '4': 'Perturbed Forecast Products', '5': 'Control and Perturbed Forecast Products', '6': 'Processed Satellite Observations', '7': 'Processed Radar Observations', '8': 'Event Probability', '9-191': 'Reserved', '192-254': 'Reserved for Local Use', '192': 'Experimental Products', '255': 'Missing'}
table_1_5 = {'0': 'Calendar Definition', '1': 'Paleontological Offset', '2': 'Calendar Definition and Paleontological Offset', '3-32767': 'Reserved', '32768-65534': 'Reserved for Local Use', '65535': 'Missing'}
table_1_6 = {'0': 'Gregorian', '1': '360-day', '2': '365-day', '3': 'Proleptic Gregorian', '4-191': 'Reserved', '192-254': 'Reserved for Local Use', '255': 'Missing'}